Index: ExternalCodeEditor_WIN32.h
===================================================================
--- ExternalCodeEditor_WIN32.h	(revision 11874)
+++ ExternalCodeEditor_WIN32.h	(working copy)
@@ -44,6 +44,7 @@
   ~ExternalCodeEditor();
   int is_editing();
   DWORD reap_editor();
+  void close_editor();
   const char *filename() { return filename_; }
   int open_editor(const char *editor_cmd, const char *code);
   int handle_changes(const char **code, int force=0);
Index: ExternalCodeEditor_WIN32.cxx
===================================================================
--- ExternalCodeEditor_WIN32.cxx	(revision 11874)
+++ ExternalCodeEditor_WIN32.cxx	(working copy)
@@ -72,7 +72,7 @@
 
 // DTOR
 ExternalCodeEditor::~ExternalCodeEditor() {
-  kill_editor();    // Kill any open editors, deletes tmp file
+  close_editor();   // close editor, delete tmp file
   set_filename(0);  // free()s filename
 }
 
@@ -132,6 +132,35 @@
   return ret;
 }
 
+// [Protected] Wait for editor to close
+void ExternalCodeEditor::close_editor() {
+  if ( G_debug ) printf("close_editor() called: pid=%ld\n", long(pinfo_.dwProcessId));
+  // Wait until editor is closed + reaped
+  while ( is_editing() ) {
+    switch ( reap_editor() ) {
+      case -1:  // error
+        fl_alert("Error reaping external editor\n"
+                 "pid=%ld file=%s", long(pinfo_.dwProcessId), filename());
+        break;
+      case 0:   // process still running
+	switch ( fl_choice("Please close external editor\npid=%ld file=%s",
+			   "Force Close",	// button 0
+			   "Closed",		// button 1
+			   0,			// button 2
+			   long(pinfo_.dwProcessId), filename() ) ) {
+	  case 0: 	// Force Close
+	    kill_editor();
+	    continue;
+	  case 1: 	// Closed? try to reap
+	    continue;
+	}
+        break;
+      default:  // process reaped
+        return;
+    }
+  }
+}
+
 // [Protected] Kill the running editor (if any) and cleanup
 //   Kills the editor, reaps the process, and removes the tmp file.
 //   The dtor calls this to ensure no editors remain running when fluid exits.
